"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = fetch;

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _isomorphicUnfetch = _interopRequireDefault(require("isomorphic-unfetch"));

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { (0, _defineProperty2["default"])(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

var RSF_VERSION_HEADER = 'x-rsf-api-version';
var apiVersion = process.env.RSF_API_VERSION || '1';
/**
 * An isomorphic implementation of the fetch API that always sends the x-rsf-api-version header.  You should
 * always use this to fetch data on both the client and server to ensure that React Storefront's
 * service worker serves responses cached by the service worker.
 *
 * @param {String} url URL to `fetch`.
 * @param {Object} opts Options passed to the `fetch` call.
 * @return {Promise} The `Promise` returned from the `fetch` call.
 */

function fetch(url) {
  var opts = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  var headers = opts.headers || {};
  headers[RSF_VERSION_HEADER] = apiVersion;
  return (0, _isomorphicUnfetch["default"])(url, _objectSpread({}, opts, {
    headers: headers
  }));
}
/**
 * @private
 * Adds x-rsf-api-version to all xhr
 */


function monkeyPatchXHR() {
  var open = XMLHttpRequest.prototype.open;

  XMLHttpRequest.prototype.open = function () {
    var res = open.apply(this, arguments);
    this.setRequestHeader(RSF_VERSION_HEADER, apiVersion);
    return res;
  };
}
/**
 * @private
 * Adds x-rsf-api-version to all fetch requests
 */


function monkeyPatchFetch() {
  // We don't add fetch if it's not there, so browsers will not try to detect it
  if (window.fetch) {
    window.fetch = fetch;
  }
}

if (typeof window !== 'undefined') {
  monkeyPatchXHR();
  monkeyPatchFetch();
}
//# sourceMappingURL=fetch.js.map