"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = SwatchProductOption;
exports.styles = void 0;

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _react = _interopRequireDefault(require("react"));

var _clsx5 = _interopRequireDefault(require("clsx"));

var _Box = require("../Box");

var _Typography = _interopRequireDefault(require("@material-ui/core/Typography"));

var _styles = require("@material-ui/core/styles");

var _Check = _interopRequireDefault(require("@material-ui/icons/Check"));

var _Image = _interopRequireDefault(require("../Image"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _Skeleton = _interopRequireDefault(require("@material-ui/lab/Skeleton"));

var styles = function styles(theme) {
  return {
    /**
     * Styles applied to the root element.
     */
    root: {},

    /**
     * Styles applied to the button element.
     */
    button: {
      position: 'relative',
      marginBottom: theme.spacing(0.5),
      padding: 2,
      borderRadius: '50%',
      backgroundColor: 'transparent',
      minWidth: 0,
      borderWidth: 1,
      borderStyle: 'solid',
      borderColor: theme.palette.grey[500],
      cursor: 'pointer',
      '&:focus': {
        outline: 0
      }
    },

    /**
     * Styles applied to the image element.
     */
    image: {
      height: '100%',
      width: '100%',
      borderRadius: '50%'
    },

    /**
     * Styles applied for mobile devices.
     */
    '@media (hover: none)': {
      SwatchButton: {
        '&:hover': {
          backgroundColor: 'transparent'
        }
      }
    },

    /**
     * Styles applied to the wrapper element of the selected icon.
     */
    checkMark: {
      transition: 'opacity 0.1s linear',
      opacity: 0,
      position: 'absolute',
      zIndex: 1,
      color: 'white',
      top: 2,
      left: 2,
      display: 'flex',
      alignItems: 'center',
      justifyContent: 'center',
      backgroundColor: 'rgba(0,0,0,0.2)',
      padding: 2,
      height: 'calc(100% - 4px)',
      width: 'calc(100% - 4px)',
      boxSizing: 'border-box',
      borderRadius: '50%',
      '.rsf-po-selected &': {
        opacity: 1
      }
    },

    /**
     * Styles applied to the wrapper element of the selected icon when this option is selected.
     */
    selected: {
      opacity: 1
    },

    /**
     * Styles applied to the label element when this option is selected.
     */
    selectedLabel: {
      fontWeight: 'bold'
    },

    /**
     * Styles applied to the skeleton and button elements when [`size`](#prop-size) is `'default'`.
     */
    "default": {
      height: 48,
      width: 48,
      '& svg': {
        height: 24,
        width: 24
      }
    },

    /**
     * Styles applied to the skeleton and button elements when [`size`](#prop-size) is `'small'`.
     */
    small: {
      height: 32,
      width: 32,
      '& svg': {
        height: 16,
        width: 16
      }
    },

    /**
     * Styles applied to the skeleton and button elements when [`size`](#prop-size) is `'tiny'`.
     */
    tiny: {
      height: 24,
      width: 24,
      '& svg': {
        height: 12,
        width: 12
      }
    }
  };
};

exports.styles = styles;
var useStyles = (0, _styles.makeStyles)(styles, {
  name: 'RSFSwatchProductOption'
});
/**
 * A variant of [`ProductOption`](/apiReference/option/ProductOption] that shows an image swatch to
 * represent a product option.
 */

function SwatchProductOption(_ref) {
  var _clsx2, _clsx3;

  var selected = _ref.selected,
      label = _ref.label,
      classes = _ref.classes,
      imageProps = _ref.imageProps,
      onClick = _ref.onClick,
      SelectedIcon = _ref.SelectedIcon,
      size = _ref.size,
      skeleton = _ref.skeleton,
      ImageComponent = _ref.ImageComponent,
      className = _ref.className,
      buttonProps = _ref.buttonProps;
  classes = useStyles({
    classes: classes
  });

  if (skeleton) {
    var _clsx;

    return _react["default"].createElement(_Skeleton["default"], {
      variant: "circle",
      style: {
        marginTop: 0,
        marginBottom: 4,
        margintLeft: 4,
        marginRight: 4
      },
      className: (0, _clsx5["default"])((_clsx = {}, (0, _defineProperty2["default"])(_clsx, buttonProps.className, true), (0, _defineProperty2["default"])(_clsx, classes[size], true), _clsx))
    });
  }

  return _react["default"].createElement(_Box.Vbox, {
    className: classes.root
  }, _react["default"].createElement("button", (0, _extends2["default"])({}, buttonProps, {
    type: "button",
    onClick: onClick,
    className: (0, _clsx5["default"])((_clsx2 = {}, (0, _defineProperty2["default"])(_clsx2, className, className != null), (0, _defineProperty2["default"])(_clsx2, classes.button, true), (0, _defineProperty2["default"])(_clsx2, classes[size], true), _clsx2))
  }), _react["default"].createElement("div", {
    className: (0, _clsx5["default"])((_clsx3 = {}, (0, _defineProperty2["default"])(_clsx3, classes.checkMark, true), (0, _defineProperty2["default"])(_clsx3, classes.selected, selected), _clsx3))
  }, _react["default"].createElement(SelectedIcon, {
    className: classes.icon
  })), _react["default"].createElement(ImageComponent, (0, _extends2["default"])({
    classes: {
      image: classes.image
    },
    fill: true,
    aspectRatio: 1
  }, imageProps))), label && _react["default"].createElement(_Typography["default"], {
    variant: "caption",
    className: (0, _clsx5["default"])((0, _defineProperty2["default"])({}, classes.selectedLabel, selected))
  }, label));
}

SwatchProductOption.propTypes = {
  /**
   * Override or extend the styles applied to the component. See [CSS API](#css) below for more details.
   */
  classes: _propTypes["default"].object,

  /**
   * A CSS class to apply to the option.
   */
  className: _propTypes["default"].string,

  /**
   * Text to display below the button.
   */
  label: _propTypes["default"].oneOfType([_propTypes["default"].string, _propTypes["default"].element]),

  /**
   * Props for the `Image` element.
   */
  imageProps: _propTypes["default"].shape(_Image["default"].propTypes),

  /**
   * Controls the size of the button.
   */
  size: _propTypes["default"].oneOf(['default', 'small', 'tiny']),

  /**
   * The component type to use to display images.
   */
  ImageComponent: _propTypes["default"].elementType,

  /**
   * If `true`, this option is selected.
   */
  selected: _propTypes["default"].bool,

  /**
   * A function to call when this option is clicked.
   */
  onClick: _propTypes["default"].func,

  /**
   * An icon component type to display for when this option is selected.
   */
  SelectedIcon: _propTypes["default"].elementType,

  /**
   * If `true`, show this option as just a skeleton.
   */
  skeleton: _propTypes["default"].bool,

  /**
   * Props to pass to the button element.
   */
  buttonProps: _propTypes["default"].object
};
SwatchProductOption.defaultProps = {
  imageProps: {},
  SelectedIcon: _Check["default"],
  ImageComponent: _Image["default"],
  size: 'default',
  buttonProps: {}
};
//# sourceMappingURL=SwatchProductOption.js.map